@@ -8,7 +8,7 @@
 #define __M_ENV_H
 
 /*
- * $Id: m_env.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: m_env.h,v 1.2 2003/03/09 19:27:08 steveg Exp $
  */
 
 struct __env
@@ -36,7 +36,7 @@ typedef struct __env *env_h ;
 #define ENV_EBADSTRING            3
 
 
-env_h env_create ( env_h ) ;
+env_h env_create ( const env_h ) ;
 void env_destroy ( env_h ) ;
 env_h env_make ( char **env_strings ) ;
 int env_addvar ( env_h, env_h from_env, char *var ) ;
