@@ -261,7 +261,7 @@ static int initial_map( mapd_s *mdp, int fd )
 {
    caddr_t addr ;
    size_t requested_length = 2 * map_unit_size ;
-   size_t mapped_length = MIN( mdp->file_size, requested_length ) ;
+   size_t mapped_length = MIN( (size_t)mdp->file_size, requested_length ) ;
    size_t bytes_left ;
    size_t bytes_in_unit ;
 
@@ -861,7 +861,7 @@ int Smorefds(int fd)
    int n_fds = 4; /* Let's bump 4 at a time for hysteresis */
 
    /* If the fd is out of range of the proposed size, make n_fds big enough */
-   if (fd > (__sio_n_descriptors+n_fds))
+   if (fd >= (__sio_n_descriptors+n_fds))
       n_fds += fd - __sio_n_descriptors;
 
 #ifdef HAVE_MMAP
