@@ -6,7 +6,7 @@
 
 
 /*
- * $Id: slog.h,v 1.2 2003/03/09 19:29:21 steveg Exp $
+ * $Id: slog.h,v 1.3 2003/05/31 21:58:58 steveg Exp $
  */
 #ifndef __SLOG_H
 #define __SLOG_H
@@ -23,7 +23,7 @@ struct syslog_parms
    int 		slp_n_xlogs ;           /* # of xlogs using syslog */
    int 		slp_logopts ;           /* used at openlog */
    int 		slp_facility ;
-   char		*slp_ident ;		/* used at openlog */
+   const char  *slp_ident ;		/* used at openlog */
    /* bool_int slp_ident_is_malloced ; */
 } ;
 
