@@ -8,7 +8,7 @@
 #define __XLOG_H
 
 /*
- * $Id: xlog.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: xlog.h,v 1.2 2003/03/09 19:30:08 steveg Exp $
  */
 
 /*
@@ -30,7 +30,7 @@
 #define XLOG_EOPEN					2
 #define XLOG_EFSTAT					3
 #define XLOG_ENOMEM					4
-#define XLOG_EBADOP					5
+#define XLOG_EWRITE					5
 
 /*
  * Interface
