@@ -74,7 +74,7 @@ void si_exit(void)
    struct intercept_s *ip = &stream_intercept_state ;
    
    if ( SIP( ip->int_priv )->accepted_connections == 0 )
-      (void) accept( INT_REMOTE( ip ), SA( NULL ), INT_NULL ) ;
+      (void) accept( INT_REMOTE( ip ), SA( NULL ), NULL ) ;
    int_exit( ip ) ;
 }
 
@@ -180,8 +180,8 @@ static status_e handle_io( psi_h iter,
 
          FD_CLR( chp->ch_local_socket, maskp ) ;
          FD_CLR( chp->ch_remote_socket, maskp ) ;
-         (void) close( chp->ch_remote_socket ) ;
-         (void) close( chp->ch_local_socket ) ;
+         (void) Sclose( chp->ch_remote_socket ) ;
+         (void) Sclose( chp->ch_local_socket ) ;
          psi_remove( iter ) ;
          FREE_CHANNEL( chp ) ;
          break ;
@@ -195,7 +195,7 @@ static status_e handle_io( psi_h iter,
 static void connection_request( struct intercept_s *ip, channel_s **chpp )
 {
    union xsockaddr      csin ;
-   int                  sin_len = 0;
+   socklen_t            sin_len = 0;
    channel_s           *chp ;
    int                  sd ;
    bool_int             addr_checked ;
@@ -236,14 +236,14 @@ static void connection_request( struct intercept_s *ip, channel_s **chpp )
          if ( result != AC_OK )
          {
             svc_log_failure( sp, cop, result ) ;
-            (void) close( sd ) ;
+            (void) Sclose( sd ) ;
             return ;
          }
       }
 
       if ( ( chp = int_newconn( ip, &csin, sd ) ) == NULL )
       {
-         (void) close( sd ) ;
+         (void) Sclose( sd ) ;
          return ;
       }
       
