@@ -176,7 +176,7 @@ static void udp_remote_to_local( struct intercept_s *ip, channel_s **chpp )
       if ( ( chp = int_newconn( ip, &packet.from, INT_REMOTE( ip ) ) ) == NULL )
          return ;
 
-      conn_setaddr( cop, &packet.from ) ;      /* for logging */
+      CONN_SETADDR( cop, &packet.from ) ;      /* for logging */
 
       if ( INTERCEPT( ip ) )
       {
@@ -254,7 +254,7 @@ static void send_data( int sd, char *buf, int len, union xsockaddr *addr )
 
 static status_e get_incoming_packet( struct intercept_s *ip, packet_s *pp )
 {
-   int from_len = 0;
+   socklen_t from_len = 0;
    const char *func = "get_incoming_packet" ;
 
    if( SC_IPV4( SVC_CONF( SERVER_SERVICE( INT_SERVER( ip ) ) ) ) )
