@@ -234,16 +234,22 @@ void tabprint( int fd, int tab_level, const char *fmt, ...)
 void drain( int sd )
 {
    char buf[ 256 ] ; /* This size is arbitrarily chosen */
-   char cc ;
+   int ret ;
    int old_val ;
 
    /* Put in non-blocking mode so we don't hang. */
    old_val = fcntl( sd, F_GETFL, FNDELAY );
-   fcntl( sd, F_SETFL, FNDELAY );
+   if ( fcntl( sd, F_SETFL, FNDELAY ) < 0 )
+   {
+      if ( debug.on )
+         msg( LOG_DEBUG, "drain",
+              "UDP socket could not be made non-blocking: %m" ) ;
+      return;
+   }
 
    do {
-      cc = recv( sd, buf, sizeof( buf ), 0 ) ;
-   } while (cc > 0);
+      ret = recv( sd, buf, sizeof( buf ), 0 ) ;
+   } while (ret > 0);
 
    /* Restore the value since the connection will be freed, not closed. */
    if (old_val >= 0)
@@ -258,7 +264,7 @@ void drain( int sd )
  */
 int parse_int(const char *str, int base, int term, int *res)
 {
-	unsigned char *endptr;
+	char *endptr;
 	long strtol_res;
 
 /* SUSv2 says:
@@ -286,6 +292,50 @@ int parse_int(const char *str, int base, int term, int *res)
 	return -1;
 }
 
+int parse_uint(const char *str, int base, int term, unsigned int *res)
+{
+	unsigned long long tmp;
+	int ret;
+	ret = parse_ull(str, base, term, &tmp);
+	*res = (unsigned int)tmp;
+	return ret;
+}
+
+int parse_ull(const char *str, int base, int term, unsigned long long *res)
+{
+	char *endptr;
+	unsigned long long strtol_res;
+
+/* SUSv2 says:
+ * "Because 0, LONG_MIN and LONG_MAX are returned on error and are also
+ * valid returns on success, an application wishing to check for error
+ * situations should set errno to 0, then call strtol(), then check errno." */
+	errno = 0;
+	strtol_res = strtoull(str, (char **)&endptr, base);
+
+	if (errno == 0 && *str != NUL) {
+		/* Special case: -1 means allow trailing whitespace */
+		if (term == -1) {
+			while (*endptr != NUL && isspace(*endptr))
+				endptr++;
+			term = NUL;
+		}
+
+		if (*endptr == term) {
+			*res = strtol_res;
+			return 0;
+		}
+	}
+
+	*res = 0;
+	return -1;
+}
+
+int parse_ubase10(const char *str, unsigned int *res)
+{
+	return parse_uint(str, 10, -1, res);
+}
+
 int parse_base10(const char *str, int *res)
 {
 	return parse_int(str, 10, -1, res);
